@@ -1,4 +1,4 @@
-"""Bootstrap"""
+"""Bootstrap."""
 
 from __future__ import annotations
 
@@ -19,7 +19,7 @@ from .pip_install.symlink import SymlinkPipInstall
 
 
 class FromAppData(BaseEmbed):
-    def __init__(self, options):
+    def __init__(self, options) -> None:
         super().__init__(options)
         self.symlinks = options.symlink_app_data
 
@@ -55,7 +55,7 @@ class FromAppData(BaseEmbed):
                         if not installer.has_image():
                             installer.build_image()
                     installer.install(creator.interpreter.version_info)
-                except Exception:
+                except Exception:  # noqa: BLE001
                     exceptions[name] = sys.exc_info()
 
             threads = [Thread(target=_install, args=(n, w)) for n, w in name_to_whl.items()]
@@ -71,7 +71,7 @@ class FromAppData(BaseEmbed):
                 raise RuntimeError("\n".join(messages))
 
     @contextmanager
-    def _get_seed_wheels(self, creator):
+    def _get_seed_wheels(self, creator):  # noqa: C901
         name_to_whl, lock, fail = {}, Lock(), {}
 
         def _get(distribution, version):
@@ -93,7 +93,7 @@ class FromAppData(BaseEmbed):
                     )
                     if result is not None:
                         break
-                except Exception as exception:
+                except Exception as exception:  # noqa: PERF203
                     logging.exception("fail")
                     failure = exception
             if failure:
@@ -124,17 +124,16 @@ class FromAppData(BaseEmbed):
         for thread in threads:
             thread.join()
         if fail:
-            raise RuntimeError(f"seed failed due to failing to download wheels {', '.join(fail.keys())}")
+            msg = f"seed failed due to failing to download wheels {', '.join(fail.keys())}"
+            raise RuntimeError(msg)
         yield name_to_whl
 
     def installer_class(self, pip_version_tuple):
-        if self.symlinks and pip_version_tuple:
-            # symlink support requires pip 19.3+
-            if pip_version_tuple >= (19, 3):
-                return SymlinkPipInstall
+        if self.symlinks and pip_version_tuple and pip_version_tuple >= (19, 3):  # symlink support requires pip 19.3+
+            return SymlinkPipInstall
         return CopyPipInstall
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         msg = f", via={'symlink' if self.symlinks else 'copy'}, app_data_dir={self.app_data}"
         base = super().__repr__()
         return f"{base[:-1]}{msg}{base[-1]}"
